@@ -2,6 +2,7 @@
 
 import requests
 from urllib.parse import urlencode, urljoin
+
 from mailerlite.constants import MAILERLITE_API_V2_URL, VALID_REQUEST_METHODS
 
 
@@ -40,6 +41,14 @@ def check_headers(headers):
         valid_headers = False
         return valid_headers, error_msg
 
+    try:
+        url = build_url('stats')
+        _, _ = get(url, headers=headers)
+    except OSError as e_res:
+        valid_headers = False
+        error_msg = e_res.args[0].content or \
+            "Something Wrong happens with the API headers"
+
     return valid_headers, error_msg
 
 
@@ -104,7 +113,7 @@ def make_request(url, method, headers=None, data=None,
         raise e
     else:
         if response.status_code >= 400:
-            print(response.json())
+            print(response.text)
             raise IOError(response)
 
         if response.status_code == 204:
