@@ -26,6 +26,8 @@ Subscriber = namedtuple('Subscriber', ['id', 'name', 'email', 'sent',
                                        'confirmation_ip',
                                        'confirmation_timestamp',
                                        'fields', 'date_subscribe',
+                                       'subscribe_date',
+                                       'webform_subscribe_date',
                                        'date_unsubscribe', 'date_created',
                                        'date_updated', 'opened_rate',
                                        'clicked_rate', 'country_id',
